summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/dateedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/dateedit.h')
-rw-r--r--kalarm/lib/dateedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalarm/lib/dateedit.h b/kalarm/lib/dateedit.h
index 7ad0a7a05..b221871a9 100644
--- a/kalarm/lib/dateedit.h
+++ b/kalarm/lib/dateedit.h
@@ -40,10 +40,10 @@ class DateEdit : public KDateEdit
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit DateEdit(TQWidget* tqparent = 0, const char* name = 0);
+ explicit DateEdit(TQWidget* parent = 0, const char* name = 0);
/** Returns true if the widget contains a valid date. */
bool isValid() const { return date().isValid(); }
/** Returns the earliest date which can be entered.
@@ -40,10 +40,10 @@ class DateEdit : public KDateEdit
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/